@@ -20,12 +20,14 @@
 #ifndef _PAM_X2GO_CHILDREN_H_
 #define _PAM_X2GO_CHILDREN_H_
 
-#define PAM_TYPE_SESSIONTYPE  1234
+#define PAM_TYPE_X2GO_USER    1234
+#define PAM_TYPE_X2GO_SERVER  1235
+#define PAM_TYPE_X2GO_COMMAND 1236
 #define ALL_GOOD_SIGNAL  "Ar, ready to authenticate cap'n"
 
 void
-pam_sm_authenticate_helper (int *stdinpipe, const char* username, const char* rhost, const char* ruser, const char* rsession);
+pam_sm_authenticate_helper (int *stdinpipe, const char* username, const char* rhost, const char* ruser, const char* rcommand);
 
 int
-session_socket_handler (struct passwd * pwdent, int readypipe, const char * ruser, const char * rhost, const char * rsession, const char * password);
+session_socket_handler (struct passwd * pwdent, int readypipe, const char * ruser, const char * rhost, const char * rcommand, const char * password);
 #endif //_PAM_X2GO_CHILDREN_H_
