@@ -10,6 +10,7 @@
 #ifndef __MOCK_PAM_H__
 #define __MOCK_PAM_H__
 
+#define LIBPAM_COMPILE
 #include <security/pam_modules.h>
 #include <security/pam_modutil.h>
 #include <security/pam_appl.h>
@@ -19,7 +20,10 @@
 typedef struct pam_handle pam_handle_t;
 
 pam_handle_t *pam_handle_new (void);
-int pam_get_item (const pam_handle_t *pamh, int type, const void **value);
-int pam_set_item (pam_handle_t *pamh, int type, const void *value);
+
+int PAM_NONNULL((1))
+pam_get_item (const pam_handle_t *pamh, int type, const void **value);
+int PAM_NONNULL((1))
+pam_set_item (pam_handle_t *pamh, int type, const void *value);
 
 #endif
